@@ -104,6 +104,11 @@ static const wxChar EnableEeschemaPrintCairo[] = wxT( "EnableEeschemaPrintCairo"
 static const wxChar DisambiguationTime[] = wxT( "DisambiguationTime" );
 static const wxChar PcbSelectionVisibilityRatio[] = wxT( "PcbSelectionVisibilityRatio" );
 static const wxChar MinimumSegmentLength[] = wxT( "MinimumSegmentLength" );
+static const wxChar OcePluginLinearDeflection[] = wxT( "OcePluginLinearDeflection" );
+static const wxChar OcePluginAngularDeflection[] = wxT( "OcePluginAngularDeflection" );
+static const wxChar TriangulateSimplificationLevel[] = wxT( "TriangulateSimplificationLevel" );
+static const wxChar TriangulateMinimumArea[] = wxT( "TriangulateMinimumArea" );
+static const wxChar EnableCacheFriendlyFracture[] = wxT( "EnableCacheFriendlyFracture" );
 } // namespace KEYS
 
 
@@ -248,6 +253,14 @@ ADVANCED_CFG::ADVANCED_CFG()
 
     m_MinimumSegmentLength      = 50;
 
+    m_OcePluginLinearDeflection = 0.14;
+    m_OcePluginAngularDeflection = 30;
+
+    m_TriangulateSimplificationLevel = 50;
+    m_TriangulateMinimumArea = 1000;
+
+    m_EnableCacheFriendlyFracture = true;
+
     loadFromConfigFile();
 }
 
@@ -444,6 +457,26 @@ void ADVANCED_CFG::loadSettings( wxConfigBase& aCfg )
                                                   &m_MinimumSegmentLength,
                                                   m_MinimumSegmentLength, 10, 1000 ) );
 
+    configParams.push_back( new PARAM_CFG_DOUBLE( true, AC_KEYS::OcePluginLinearDeflection,
+                                                    &m_OcePluginLinearDeflection,
+                                                    m_OcePluginLinearDeflection, 0.01, 1.0 ) );
+
+    configParams.push_back( new PARAM_CFG_DOUBLE( true, AC_KEYS::OcePluginAngularDeflection,
+                                                    &m_OcePluginAngularDeflection,
+                                                    m_OcePluginAngularDeflection, 0.01, 360.0 ) );
+
+    configParams.push_back( new PARAM_CFG_INT( true, AC_KEYS::TriangulateSimplificationLevel,
+                                                    &m_TriangulateSimplificationLevel,
+                                                    m_TriangulateSimplificationLevel, 0, 1000 ) );
+
+    configParams.push_back( new PARAM_CFG_INT( true, AC_KEYS::TriangulateMinimumArea,
+                                                    &m_TriangulateMinimumArea,
+                                                    m_TriangulateMinimumArea, 0, 100000 ) );
+
+    configParams.push_back( new PARAM_CFG_BOOL( true, AC_KEYS::EnableCacheFriendlyFracture,
+                                                &m_EnableCacheFriendlyFracture,
+                                                m_EnableCacheFriendlyFracture ) );
+
     // Special case for trace mask setting...we just grab them and set them immediately
     // Because we even use wxLogTrace inside of advanced config
     wxString traceMasks;
