@@ -28,15 +28,25 @@
 #include <wx/base64.h>
 #include <wx/log.h>
 #include <wx/mstream.h>
+#include <boost/algorithm/string/join.hpp>
+
 #include <advanced_config.h>
 #include <base_units.h>
 #include <build_version.h>
-#include <trace_helpers.h>
+#include <ee_selection.h>
+#include <font/fontconfig.h>
+#include <io/kicad/kicad_io_utils.h>
 #include <locale_io.h>
+#include <progress_reporter.h>
+#include <schematic.h>
+#include <schematic_lexer.h>
 #include <sch_bitmap.h>
 #include <sch_bus_entry.h>
-#include <sch_symbol.h>
 #include <sch_edit_frame.h>       // SYMBOL_ORIENTATION_T
+#include <sch_io/kicad_sexpr/sch_io_kicad_sexpr.h>
+#include <sch_io/kicad_sexpr/sch_io_kicad_sexpr_common.h>
+#include <sch_io/kicad_sexpr/sch_io_kicad_sexpr_lib_cache.h>
+#include <sch_io/kicad_sexpr/sch_io_kicad_sexpr_parser.h>
 #include <sch_junction.h>
 #include <sch_line.h>
 #include <sch_shape.h>
@@ -62,9 +72,9 @@
 #include <symbol_lib_table.h>  // for PropPowerSymsOnly definition.
 #include <ee_selection.h>
 #include <string_utils.h>
+#include <symbol_lib_table.h>  // for PropPowerSymsOnly definition.
+#include <trace_helpers.h>
 #include <wx_filename.h>       // for ::ResolvePossibleSymlinks()
-#include <progress_reporter.h>
-#include <boost/algorithm/string/join.hpp>
 
 using namespace TSCHEMATIC_T;
 
@@ -109,6 +119,9 @@ SCH_SHEET* SCH_IO_KICAD_SEXPR::LoadSchematicFile( const wxString& aFileName, SCH
 
     wxFileName fn = aFileName;
 
+    // Show the font substitution warnings
+    fontconfig::FONTCONFIG::SetReporter( &WXLOG_REPORTER::GetInstance() );
+
     // Unfortunately child sheet file names the legacy schematic file format are not fully
     // qualified and are always appended to the project path.  The aFileName attribute must
     // always be an absolute path so the project path can be used for load child sheet files.
@@ -783,75 +796,79 @@ void SCH_IO_KICAD_SEXPR::saveSymbol( SCH_SYMBOL* aSymbol, const SCHEMATIC& aSche
 
     if( !aSymbol->GetInstances().empty() )
     {
+        std::map<KIID, std::vector<SCH_SYMBOL_INSTANCE>> projectInstances;
+
         m_out->Print( aNestLevel + 1, "(instances\n" );
 
+        wxString projectName;
         KIID lastProjectUuid;
         KIID rootSheetUuid = aSchematic.Root().m_Uuid;
         SCH_SHEET_LIST fullHierarchy = aSchematic.GetSheets();
-        bool project_open = false;
 
-        for( size_t i = 0; i < aSymbol->GetInstances().size(); i++ )
+        for( const SCH_SYMBOL_INSTANCE& inst : aSymbol->GetInstances() )
         {
             // Zero length KIID_PATH objects are not valid and will cause a crash below.
-            wxCHECK2( aSymbol->GetInstances()[i].m_Path.size(), continue );
+            wxCHECK2( inst.m_Path.size(), continue );
 
             // If the instance data is part of this design but no longer has an associated sheet
             // path, don't save it.  This prevents large amounts of orphaned instance data for the
             // current project from accumulating in the schematic files.
-            //
-            // Keep all instance data when copying to the clipboard.  It may be needed on paste.
-            if( !aForClipboard
-              && ( aSymbol->GetInstances()[i].m_Path[0] == rootSheetUuid )
-              && !fullHierarchy.GetSheetPathByKIIDPath( aSymbol->GetInstances()[i].m_Path ) )
-            {
-                if( project_open && ( ( i + 1 == aSymbol->GetInstances().size() )
-                  || lastProjectUuid != aSymbol->GetInstances()[i+1].m_Path[0] ) )
-                {
-                    m_out->Print( aNestLevel + 2, ")\n" );  // Closes `project`.
-                    project_open = false;
-                }
+            bool isOrphaned = ( inst.m_Path[0] == rootSheetUuid )
+                              && !fullHierarchy.GetSheetPathByKIIDPath( inst.m_Path );
 
+            // Keep all instance data when copying to the clipboard.  They may be needed on paste.
+            if( !aForClipboard && isOrphaned )
                 continue;
-            }
 
-            if( lastProjectUuid != aSymbol->GetInstances()[i].m_Path[0] )
+            auto it = projectInstances.find( inst.m_Path[0] );
+
+            if( it == projectInstances.end() )
             {
-                wxString projectName;
-
-                if( aSymbol->GetInstances()[i].m_Path[0] == rootSheetUuid )
-                    projectName = aSchematic.Prj().GetProjectName();
-                else
-                    projectName = aSymbol->GetInstances()[i].m_ProjectName;
-
-                lastProjectUuid = aSymbol->GetInstances()[i].m_Path[0];
-                m_out->Print( aNestLevel + 2, "(project %s\n",
-                              m_out->Quotew( projectName ).c_str() );
-                project_open = true;
+                projectInstances[ inst.m_Path[0] ] = { inst };
             }
-
-            wxString path;
-            KIID_PATH tmp = aSymbol->GetInstances()[i].m_Path;
-
-            if( aForClipboard && aRelativePath )
-                tmp.MakeRelativeTo( aRelativePath->Path() );
-
-            path = tmp.AsString();
-
-            m_out->Print( aNestLevel + 3, "(path %s\n",
-                          m_out->Quotew( path ).c_str() );
-            m_out->Print( aNestLevel + 4, "(reference %s) (unit %d)\n",
-                          m_out->Quotew( aSymbol->GetInstances()[i].m_Reference ).c_str(),
-                          aSymbol->GetInstances()[i].m_Unit );
-            m_out->Print( aNestLevel + 3, ")\n" );
-
-            if( project_open && ( ( i + 1 == aSymbol->GetInstances().size() )
-              || lastProjectUuid != aSymbol->GetInstances()[i+1].m_Path[0] ) )
+            else
             {
-                m_out->Print( aNestLevel + 2, ")\n" );  // Closes `project`.
-                project_open = false;
+                it->second.emplace_back( inst );
             }
         }
 
+        for( auto& [uuid, instances] : projectInstances )
+        {
+            wxCHECK2( instances.size(), continue );
+
+            // Sort project instances by KIID_PATH.
+            std::sort( instances.begin(), instances.end(),
+                       []( SCH_SYMBOL_INSTANCE& aLhs, SCH_SYMBOL_INSTANCE& aRhs )
+                       {
+                           return aLhs.m_Path < aRhs.m_Path;
+                       } );
+
+            projectName = instances[0].m_ProjectName;
+
+            m_out->Print( aNestLevel + 2, "(project %s\n",
+                          m_out->Quotew( projectName ).c_str() );
+
+            for( const SCH_SYMBOL_INSTANCE& instance : instances )
+            {
+                wxString path;
+                KIID_PATH tmp = instance.m_Path;
+
+                if( aForClipboard && aRelativePath )
+                    tmp.MakeRelativeTo( aRelativePath->Path() );
+
+                path = tmp.AsString();
+
+                m_out->Print( aNestLevel + 3, "(path %s\n",
+                              m_out->Quotew( path ).c_str() );
+                m_out->Print( aNestLevel + 4, "(reference %s) (unit %d)\n",
+                              m_out->Quotew( instance.m_Reference ).c_str(),
+                              instance.m_Unit );
+                m_out->Print( aNestLevel + 3, ")\n" );
+            }
+
+            m_out->Print( aNestLevel + 2, ")\n" );  // Closes `project`.
+        }
+
         m_out->Print( aNestLevel + 1, ")\n" );  // Closes `instances`.
     }
 
@@ -1412,6 +1429,9 @@ void SCH_IO_KICAD_SEXPR::saveInstances( const std::vector<SCH_SHEET_INSTANCE>& a
 void SCH_IO_KICAD_SEXPR::cacheLib( const wxString& aLibraryFileName,
                                    const STRING_UTF8_MAP* aProperties )
 {
+    // Suppress font substitution warnings
+    fontconfig::FONTCONFIG::SetReporter( nullptr );
+
     if( !m_cache || !m_cache->IsFile( aLibraryFileName ) || m_cache->IsFileChanged() )
     {
         // a spectacular episode in memory management:
