@@ -39,25 +39,25 @@
 
 DIALOG_TRACK_VIA_PROPERTIES::DIALOG_TRACK_VIA_PROPERTIES( PCB_BASE_FRAME* aParent,
                                                           const PCB_SELECTION& aItems ) :
-    DIALOG_TRACK_VIA_PROPERTIES_BASE( aParent ),
-    m_frame( aParent ),
-    m_items( aItems ),
-    m_trackStartX( aParent, m_TrackStartXLabel, m_TrackStartXCtrl, nullptr ),
-    m_trackStartY( aParent, m_TrackStartYLabel, m_TrackStartYCtrl, m_TrackStartYUnit ),
-    m_trackEndX( aParent, m_TrackEndXLabel, m_TrackEndXCtrl, nullptr ),
-    m_trackEndY( aParent, m_TrackEndYLabel, m_TrackEndYCtrl, m_TrackEndYUnit ),
-    m_trackWidth( aParent, m_TrackWidthLabel, m_TrackWidthCtrl, m_TrackWidthUnit ),
-    m_viaX( aParent, m_ViaXLabel, m_ViaXCtrl, nullptr ),
-    m_viaY( aParent, m_ViaYLabel, m_ViaYCtrl, m_ViaYUnit ),
-    m_viaDiameter( aParent, m_ViaDiameterLabel, m_ViaDiameterCtrl, m_ViaDiameterUnit ),
-    m_viaDrill( aParent, m_ViaDrillLabel, m_ViaDrillCtrl, m_ViaDrillUnit ),
-    m_teardropHDPercent( aParent, m_stHDRatio, m_tcHDRatio, m_stHDRatioUnits ),
-    m_teardropLenPercent( aParent, m_stLenPercentLabel, m_tcLenPercent, m_stLenPercentUnits ),
-    m_teardropMaxLen( aParent, m_stMaxLen, m_tcTdMaxLen, m_stMaxLenUnits ),
-    m_teardropHeightPercent( aParent, m_stHeightPercentLabel, m_tcHeightPercent, m_stHeightPercentUnits ),
-    m_teardropMaxHeight( aParent, m_stMaxHeight, m_tcMaxHeight, m_stMaxHeightUnits ),
-    m_tracks( false ),
-    m_vias( false )
+        DIALOG_TRACK_VIA_PROPERTIES_BASE( aParent ),
+        m_frame( aParent ),
+        m_items( aItems ),
+        m_trackStartX( aParent, m_TrackStartXLabel, m_TrackStartXCtrl, nullptr ),
+        m_trackStartY( aParent, m_TrackStartYLabel, m_TrackStartYCtrl, m_TrackStartYUnit ),
+        m_trackEndX( aParent, m_TrackEndXLabel, m_TrackEndXCtrl, nullptr ),
+        m_trackEndY( aParent, m_TrackEndYLabel, m_TrackEndYCtrl, m_TrackEndYUnit ),
+        m_trackWidth( aParent, m_TrackWidthLabel, m_TrackWidthCtrl, m_TrackWidthUnit ),
+        m_viaX( aParent, m_ViaXLabel, m_ViaXCtrl, nullptr ),
+        m_viaY( aParent, m_ViaYLabel, m_ViaYCtrl, m_ViaYUnit ),
+        m_viaDiameter( aParent, m_ViaDiameterLabel, m_ViaDiameterCtrl, m_ViaDiameterUnit ),
+        m_viaDrill( aParent, m_ViaDrillLabel, m_ViaDrillCtrl, m_ViaDrillUnit ),
+        m_teardropHDPercent( aParent, m_stHDRatio, m_tcHDRatio, m_stHDRatioUnits ),
+        m_teardropLenPercent( aParent, m_stLenPercentLabel, m_tcLenPercent, nullptr ),
+        m_teardropMaxLen( aParent, m_stMaxLen, m_tcTdMaxLen, m_stMaxLenUnits ),
+        m_teardropWidthPercent( aParent, m_stWidthPercentLabel, m_tcWidthPercent, nullptr ),
+        m_teardropMaxWidth( aParent, m_stMaxWidthLabel, m_tcMaxWidth, m_stMaxWidthUnits ),
+        m_tracks( false ),
+        m_vias( false )
 {
     m_useCalculatedSize = true;
 
@@ -70,7 +70,7 @@ DIALOG_TRACK_VIA_PROPERTIES::DIALOG_TRACK_VIA_PROPERTIES( PCB_BASE_FRAME* aParen
 
     m_teardropHDPercent.SetUnits( EDA_UNITS::PERCENT );
     m_teardropLenPercent.SetUnits( EDA_UNITS::PERCENT );
-    m_teardropHeightPercent.SetUnits( EDA_UNITS::PERCENT );
+    m_teardropWidthPercent.SetUnits( EDA_UNITS::PERCENT );
 
     m_minTrackWidthHint->SetFont( KIUI::GetInfoFont( this ).Italic() );
 
@@ -101,8 +101,6 @@ DIALOG_TRACK_VIA_PROPERTIES::DIALOG_TRACK_VIA_PROPERTIES( PCB_BASE_FRAME* aParen
 
     bool nets = false;
     int  net = 0;
-    bool tracksMatchNetclassValues = true;
-    bool viasMatchNetclassValues = true;
     bool hasLocked = false;
     bool hasUnlocked = false;
 
@@ -153,7 +151,6 @@ DIALOG_TRACK_VIA_PROPERTIES::DIALOG_TRACK_VIA_PROPERTIES( PCB_BASE_FRAME* aParen
                     m_trackEndX.SetValue( t->GetEnd().x );
                     m_trackEndY.SetValue( t->GetEnd().y );
                     m_trackWidth.SetValue( t->GetWidth() );
-                    m_trackDesignRules->SetValue( false );
                     track_selection_layer = t->GetLayer();
                     m_tracks = true;
                 }
@@ -178,16 +175,6 @@ DIALOG_TRACK_VIA_PROPERTIES::DIALOG_TRACK_VIA_PROPERTIES( PCB_BASE_FRAME* aParen
                         track_selection_layer = UNDEFINED_LAYER;
                 }
 
-                if( tracksMatchNetclassValues )
-                {
-                    MINOPTMAX<int> constraint = t->GetWidthConstraint();
-
-                    if( constraint.HasOpt() )
-                        tracksMatchNetclassValues &= constraint.Opt() == t->GetWidth();
-                    else if( constraint.Min() > 0 )
-                        tracksMatchNetclassValues &= constraint.Min() == t->GetWidth();
-                }
-
                 if( t->IsLocked() )
                     hasLocked = true;
                 else
@@ -216,9 +203,9 @@ DIALOG_TRACK_VIA_PROPERTIES::DIALOG_TRACK_VIA_PROPERTIES( PCB_BASE_FRAME* aParen
                     m_cbTeardrops->SetValue( v->GetTeardropParams().m_Enabled );
                     m_cbTeardropsUseNextTrack->SetValue( v->GetTeardropParams().m_AllowUseTwoTracks );
                     m_teardropMaxLen.SetValue( v->GetTeardropParams().m_TdMaxLen );
-                    m_teardropMaxHeight.SetValue( v->GetTeardropParams().m_TdMaxWidth );
+                    m_teardropMaxWidth.SetValue( v->GetTeardropParams().m_TdMaxWidth );
                     m_teardropLenPercent.SetDoubleValue( v->GetTeardropParams().m_BestLengthRatio*100.0 );
-                    m_teardropHeightPercent.SetDoubleValue( v->GetTeardropParams().m_BestWidthRatio*100.0 );
+                    m_teardropWidthPercent.SetDoubleValue( v->GetTeardropParams().m_BestWidthRatio*100.0 );
                     m_teardropHDPercent.SetDoubleValue( v->GetTeardropParams().m_WidthtoSizeFilterRatio*100.0 );
                     m_curvedEdges->SetValue( v->GetTeardropParams().IsCurved() );
                     m_curvePointsCtrl->SetValue( v->GetTeardropParams().m_CurveSegCount );
@@ -266,14 +253,14 @@ DIALOG_TRACK_VIA_PROPERTIES::DIALOG_TRACK_VIA_PROPERTIES( PCB_BASE_FRAME* aParen
                     if( m_teardropMaxLen.GetValue() != v->GetTeardropParams().m_TdMaxLen )
                         m_teardropMaxLen.SetValue( INDETERMINATE_STATE );
 
-                    if( m_teardropMaxHeight.GetValue() != v->GetTeardropParams().m_TdMaxWidth )
-                        m_teardropMaxHeight.SetValue( INDETERMINATE_STATE );
+                    if( m_teardropMaxWidth.GetValue() != v->GetTeardropParams().m_TdMaxWidth )
+                        m_teardropMaxWidth.SetValue( INDETERMINATE_STATE );
 
                     if( m_teardropLenPercent.GetDoubleValue() != v->GetTeardropParams().m_BestLengthRatio *100.0 )
                         m_teardropLenPercent.SetValue( INDETERMINATE_STATE );
 
-                    if( m_teardropHeightPercent.GetDoubleValue() != v->GetTeardropParams().m_BestWidthRatio *100.0 )
-                        m_teardropHeightPercent.SetValue( INDETERMINATE_STATE );
+                    if( m_teardropWidthPercent.GetDoubleValue() != v->GetTeardropParams().m_BestWidthRatio *100.0 )
+                        m_teardropWidthPercent.SetValue( INDETERMINATE_STATE );
 
                     if( m_teardropHDPercent.GetDoubleValue() != v->GetTeardropParams().m_WidthtoSizeFilterRatio*100.0 )
                         m_teardropHDPercent.SetValue( INDETERMINATE_STATE );
@@ -285,23 +272,6 @@ DIALOG_TRACK_VIA_PROPERTIES::DIALOG_TRACK_VIA_PROPERTIES( PCB_BASE_FRAME* aParen
                     }
                 }
 
-                if( viasMatchNetclassValues )
-                {
-                    MINOPTMAX<int> constraint = v->GetWidthConstraint();
-
-                    if( constraint.HasOpt() )
-                        viasMatchNetclassValues &= constraint.Opt() == v->GetWidth();
-                    else if( constraint.Min() > 0 )
-                        viasMatchNetclassValues &= constraint.Min() == v->GetWidth();
-
-                    constraint = v->GetDrillConstraint();
-
-                    if( constraint.HasOpt() )
-                        viasMatchNetclassValues &= constraint.Opt() == v->GetDrillValue();
-                    else if( constraint.Min() > 0 )
-                        viasMatchNetclassValues &= constraint.Min() == v->GetDrillValue();
-                }
-
                 if( v->IsLocked() )
                     hasLocked = true;
                 else
@@ -376,17 +346,6 @@ DIALOG_TRACK_VIA_PROPERTIES::DIALOG_TRACK_VIA_PROPERTIES( PCB_BASE_FRAME* aParen
             m_netSelector->Disable();
         }
 
-        if( viasMatchNetclassValues )
-        {
-            m_viaDesignRules->SetValue( true );
-
-            m_predefinedViaSizesLabel->Enable( false );
-            m_predefinedViaSizesCtrl->Enable( false );
-            m_predefinedViaSizesUnits->Enable( false );
-            m_viaDiameter.Enable( false );
-            m_viaDrill.Enable( false );
-        }
-
         int viaSelection = wxNOT_FOUND;
 
         // 0 is the netclass place-holder
@@ -433,16 +392,6 @@ DIALOG_TRACK_VIA_PROPERTIES::DIALOG_TRACK_VIA_PROPERTIES( PCB_BASE_FRAME* aParen
 
     if( m_tracks )
     {
-        if( tracksMatchNetclassValues )
-        {
-            m_trackDesignRules->SetValue( true );
-
-            m_predefinedTrackWidthsLabel->Enable( false );
-            m_predefinedTrackWidthsCtrl->Enable( false );
-            m_predefinedTrackWidthsUnits->Enable( false );
-            m_trackWidth.Enable( false );
-        }
-
         int widthSelection = wxNOT_FOUND;
 
         // 0 is the netclass place-holder
@@ -645,19 +594,8 @@ bool DIALOG_TRACK_VIA_PROPERTIES::TransferDataFromWindow()
                 if( !m_trackEndY.IsIndeterminate() )
                     t->SetEnd( VECTOR2I( t->GetEnd().x, m_trackEndY.GetIntValue() ) );
 
-                if( m_trackDesignRules->IsChecked() )
-                {
-                    MINOPTMAX<int> constraint = t->GetWidthConstraint();
-
-                    if( constraint.HasOpt() )
-                        t->SetWidth( constraint.Opt() );
-                    else if( constraint.Min() > 0 )
-                        t->SetWidth( constraint.Min() );
-                }
-                else if( !m_trackWidth.IsIndeterminate() )
-                {
+                if( !m_trackWidth.IsIndeterminate() )
                     t->SetWidth( m_trackWidth.GetIntValue() );
-                }
 
                 int layer = m_TrackLayerCtrl->GetLayerSelection();
 
@@ -728,30 +666,11 @@ bool DIALOG_TRACK_VIA_PROPERTIES::TransferDataFromWindow()
 
                 v->SanitizeLayers();
 
-                if( m_viaDesignRules->IsChecked() )
-                {
-                    MINOPTMAX<int> constraint = v->GetWidthConstraint();
+                if( !m_viaDiameter.IsIndeterminate() )
+                    v->SetWidth( m_viaDiameter.GetIntValue() );
 
-                    if( constraint.HasOpt() )
-                        v->SetWidth( constraint.Opt() );
-                    else if( constraint.Min() > 0 )
-                        v->SetWidth( constraint.Min() );
-
-                    constraint = v->GetDrillConstraint();
-
-                    if( constraint.HasOpt() )
-                        v->SetDrill( constraint.Opt() );
-                    else if( constraint.Min() > 0 )
-                        v->SetDrill( constraint.Min() );
-                }
-                else
-                {
-                    if( !m_viaDiameter.IsIndeterminate() )
-                        v->SetWidth( m_viaDiameter.GetIntValue() );
-
-                    if( !m_viaDrill.IsIndeterminate() )
-                        v->SetDrill( m_viaDrill.GetIntValue() );
-                }
+                if( !m_viaDrill.IsIndeterminate() )
+                    v->SetDrill( m_viaDrill.GetIntValue() );
 
                 TEARDROP_PARAMETERS* targetParams = &v->GetTeardropParams();
 
@@ -764,14 +683,15 @@ bool DIALOG_TRACK_VIA_PROPERTIES::TransferDataFromWindow()
                 if( !m_teardropMaxLen.IsIndeterminate() )
                     targetParams->m_TdMaxLen = m_teardropMaxLen.GetIntValue();
 
-                if( !m_teardropMaxHeight.IsIndeterminate() )
-                    targetParams->m_TdMaxWidth = m_teardropMaxHeight.GetIntValue();
+                if( !m_teardropMaxWidth.IsIndeterminate() )
+                    targetParams->m_TdMaxWidth = m_teardropMaxWidth.GetIntValue();
 
                 if( !m_teardropLenPercent.IsIndeterminate() )
                     targetParams->m_BestLengthRatio = m_teardropLenPercent.GetDoubleValue() / 100.0;
 
-                if( !m_teardropHeightPercent.IsIndeterminate() )
-                    targetParams->m_BestWidthRatio = m_teardropHeightPercent.GetDoubleValue() / 100.0;
+                if( !m_teardropWidthPercent.IsIndeterminate() )
+                    targetParams->m_BestWidthRatio =
+                            m_teardropWidthPercent.GetDoubleValue() / 100.0;
 
                 if( !m_teardropHDPercent.IsIndeterminate() )
                     targetParams->m_WidthtoSizeFilterRatio = m_teardropHDPercent.GetDoubleValue() / 100.0;
@@ -884,18 +804,6 @@ void DIALOG_TRACK_VIA_PROPERTIES::onViaNotFreeClicked( wxCommandEvent& aEvent )
 }
 
 
-void DIALOG_TRACK_VIA_PROPERTIES::onTrackNetclassCheck( wxCommandEvent& aEvent )
-{
-    bool enableNC = aEvent.IsChecked();
-
-    m_predefinedTrackWidthsLabel->Enable( !enableNC );
-    m_predefinedTrackWidthsCtrl->Enable( !enableNC );
-    m_predefinedTrackWidthsUnits->Enable( !enableNC );
-
-    m_trackWidth.Enable( !enableNC );
-}
-
-
 void DIALOG_TRACK_VIA_PROPERTIES::onWidthSelect( wxCommandEvent& aEvent )
 {
     m_TrackWidthCtrl->ChangeValue( m_predefinedTrackWidthsCtrl->GetStringSelection() );
@@ -909,19 +817,6 @@ void DIALOG_TRACK_VIA_PROPERTIES::onWidthEdit( wxCommandEvent& aEvent )
 }
 
 
-void DIALOG_TRACK_VIA_PROPERTIES::onViaNetclassCheck( wxCommandEvent& aEvent )
-{
-    bool enableNC = aEvent.IsChecked();
-
-    m_predefinedViaSizesLabel->Enable( !enableNC );
-    m_predefinedViaSizesCtrl->Enable( !enableNC );
-    m_predefinedViaSizesUnits->Enable( !enableNC );
-
-    m_viaDiameter.Enable( !enableNC );
-    m_viaDrill.Enable( !enableNC );
-}
-
-
 void DIALOG_TRACK_VIA_PROPERTIES::onViaSelect( wxCommandEvent& aEvent )
 {
     VIA_DIMENSION* viaDimension = static_cast<VIA_DIMENSION*> ( aEvent.GetClientData() );
