@@ -35,6 +35,7 @@
 #include <dialogs/dialog_unit_entry.h>
 #include <collectors.h>
 #include <scoped_set_reset.h>
+#include <core/mirror.h>
 
 #include <board_design_settings.h>
 #include <drc/drc_engine.h>
@@ -307,9 +308,8 @@ public:
     {
         if( !this->HasFlag( IN_EDIT ) )
         {
-            RotatePoint( m_origin, aRotCentre, aAngle );
+            PCB_GENERATOR::Rotate( aRotCentre, aAngle );
             RotatePoint( m_end, aRotCentre, aAngle );
-            PCB_GROUP::Rotate( aRotCentre, aAngle );
 
             if( m_baseLine )
                 m_baseLine->Rotate( aAngle, aRotCentre );
@@ -319,6 +319,24 @@ public:
         }
     }
 
+    void Flip( const VECTOR2I& aCentre, bool aFlipLeftRight ) override
+    {
+        if( !this->HasFlag( IN_EDIT ) )
+        {
+            PCB_GENERATOR::Flip( aCentre, aFlipLeftRight );
+            if( aFlipLeftRight )
+                MIRROR( m_end.x, aCentre.x );
+            else
+                MIRROR( m_end.y, aCentre.y );
+
+            if( m_baseLine )
+                m_baseLine->Mirror( aFlipLeftRight, !aFlipLeftRight, aCentre );
+
+            if( m_baseLineCoupled )
+                m_baseLineCoupled->Mirror( aFlipLeftRight, !aFlipLeftRight, aCentre );
+        }
+    }
+
     const BOX2I GetBoundingBox() const override
     {
         return getOutline().BBox();
@@ -1438,6 +1456,8 @@ void PCB_TUNING_PATTERN::EditPush( GENERATOR_TOOL* aTool, BOARD* aBoard, BOARD_C
 
         for( BOARD_ITEM* item : routerAddedItems )
         {
+            aCommit->Add( item );
+
             if( PCB_TRACK* track = dynamic_cast<PCB_TRACK*>( item ) )
             {
                 if( bounds.PointInside( track->GetStart(), epsilon )
@@ -1447,8 +1467,6 @@ void PCB_TUNING_PATTERN::EditPush( GENERATOR_TOOL* aTool, BOARD* aBoard, BOARD_C
                     aCommit->Stage( item, CHT_GROUP );
                 }
             }
-
-            aCommit->Add( item );
         }
     }
 
@@ -2280,7 +2298,7 @@ int DRAWING_TOOL::PlaceTuningPattern( const TOOL_EVENT& aEvent )
 
                 if( collector.GetCount() > 0 )
                 {
-                    double min_dist_sq = std::numeric_limits<double>().max();
+                    double min_dist_sq = std::numeric_limits<double>::max();
 
                     for( EDA_ITEM* candidate : collector )
                     {
@@ -2323,8 +2341,8 @@ int DRAWING_TOOL::PlaceTuningPattern( const TOOL_EVENT& aEvent )
 
                 if( dynamic_cast<PCB_TUNING_PATTERN*>( m_pickerItem->GetParentGroup() ) )
                 {
-                    m_frame->ShowInfoBarWarning(
-                            _( "Unable to tune segments inside other tuning patterns." ) );
+                    m_frame->ShowInfoBarWarning( _( "Unable to tune segments inside other "
+                                                    "tuning patterns." ) );
                 }
                 else
                 {
@@ -2381,6 +2399,10 @@ int DRAWING_TOOL::PlaceTuningPattern( const TOOL_EVENT& aEvent )
                 m_tuningPattern->SetSpacing( placer->MeanderSettings().m_spacing );
                 updateTuningPattern();
             }
+            else
+            {
+                m_frame->ShowInfoBarWarning( _( "Select a track to tune first." ) );
+            }
         }
         else if( evt->IsAction( &PCB_ACTIONS::amplIncrease )
                  || evt->IsAction( &PCB_ACTIONS::amplDecrease ) )
@@ -2393,8 +2415,13 @@ int DRAWING_TOOL::PlaceTuningPattern( const TOOL_EVENT& aEvent )
                 m_tuningPattern->SetMaxAmplitude( placer->MeanderSettings().m_maxAmplitude );
                 updateTuningPattern();
             }
+            else
+            {
+                m_frame->ShowInfoBarWarning( _( "Select a track to tune first." ) );
+            }
         }
-        else if( evt->IsAction( &PCB_ACTIONS::properties ) )
+        else if( evt->IsAction( &PCB_ACTIONS::properties )
+                || evt->IsAction( &PCB_ACTIONS::lengthTunerSettings ) )
         {
             if( m_tuningPattern )
             {
@@ -2414,6 +2441,10 @@ int DRAWING_TOOL::PlaceTuningPattern( const TOOL_EVENT& aEvent )
                 if( dlg.ShowModal() == wxID_OK )
                     updateTuningPattern();
             }
+            else
+            {
+                m_frame->ShowInfoBarWarning( _( "Select a track to tune first." ) );
+            }
         }
         // TODO: It'd be nice to be able to say "don't allow any non-trivial editing actions",
         // but we don't at present have that, so we just knock out some of the egregious ones.
